@@ -6,6 +6,9 @@ Lokalise API v2 official Python interface
 :license: BSD 3 Clause License, see LICENSE for more details.
 """
 
+from . import errors as errors
 from .client import Client
-from .oauth_client import OAuthClient
 from .oauth2.auth import Auth
+from .oauth_client import OAuthClient
+
+__all__ = ["Client", "Auth", "OAuthClient", "errors"]
