@@ -3,33 +3,33 @@ lokalise.client_methods.contributors
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 This module contains API client definition for contributors.
 """
-from typing import Optional, Union, Dict, List, Any
-from lokalise.models.contributor import ContributorModel
+
+from typing import Any
+
 from lokalise.collections.contributors import ContributorsCollection
+from lokalise.models.contributor import ContributorModel
+
 from .endpoint_provider import EndpointProviderMixin
 
 
 class ContributorMethods(EndpointProviderMixin):
-    """Contributor client methods.
-    """
+    """Contributor client methods."""
 
-    def contributors(self,
-                     project_id: str,
-                     params: Optional[Dict[str, Union[int, str]]] = None
-                     ) -> ContributorsCollection:
+    def contributors(
+        self, project_id: str, params: dict[str, int | str] | None = None
+    ) -> ContributorsCollection:
         """Fetches all contributors for the given project.
 
         :param str project_id: ID of the project to fetch contributors for.
         :param dict params: (optional) Pagination params
         :return: Collection of contributors
         """
-        raw_contributors = self.get_endpoint("contributors"). \
-            all(parent_id=project_id, params=params)
+        raw_contributors = self.get_endpoint("contributors").all(
+            parent_id=project_id, params=params
+        )
         return ContributorsCollection(raw_contributors)
 
-    def contributor(self,
-                    project_id: str,
-                    contributor_id: Union[str, int]) -> ContributorModel:
+    def contributor(self, project_id: str, contributor_id: str | int) -> ContributorModel:
         """Fetches a single contributor.
 
         :param str project_id: ID of the project
@@ -37,25 +37,25 @@ class ContributorMethods(EndpointProviderMixin):
         :type contributor_id: int or str
         :return: Contributor model
         """
-        raw_contributor = self.get_endpoint("contributors"). \
-            find(parent_id=project_id, resource_id=contributor_id)
+        raw_contributor = self.get_endpoint("contributors").find(
+            parent_id=project_id, resource_id=contributor_id
+        )
         return ContributorModel(raw_contributor)
 
-    def current_contributor(self,
-                            project_id: str) -> ContributorModel:
+    def current_contributor(self, project_id: str) -> ContributorModel:
         """Fetches current contributor (on per-token basis).
 
         :param str project_id: ID of the project
         :return: Contributor model
         """
-        raw_contributor = self.get_endpoint("contributors"). \
-            find(parent_id=project_id, resource_id="me")
+        raw_contributor = self.get_endpoint("contributors").find(
+            parent_id=project_id, resource_id="me"
+        )
         return ContributorModel(raw_contributor)
 
-    def create_contributors(self,
-                            project_id: str,
-                            params: Union[Dict[str, Any], List[Dict]]
-                            ) -> ContributorsCollection:
+    def create_contributors(
+        self, project_id: str, params: dict[str, Any] | list[dict[str, Any]]
+    ) -> ContributorsCollection:
         """Creates one or more contributors inside the project
 
         :param str project_id: ID of the project
@@ -64,17 +64,14 @@ class ContributorMethods(EndpointProviderMixin):
         :return: Contributors collection
         """
         raw_contributors = self.get_endpoint("contributors").create(
-            params=params,
-            wrapper_attr="contributors",
-            parent_id=project_id
+            params=params, wrapper_attr="contributors", parent_id=project_id
         )
 
         return ContributorsCollection(raw_contributors)
 
-    def update_contributor(self,
-                           project_id: str,
-                           contributor_id: Union[str, int],
-                           params: Dict[str, Any]) -> ContributorModel:
+    def update_contributor(
+        self, project_id: str, contributor_id: str | int, params: dict[str, Any]
+    ) -> ContributorModel:
         """Updates a single contributor.
 
         :param str project_id: ID of the project
@@ -84,14 +81,11 @@ class ContributorMethods(EndpointProviderMixin):
         :return: Contributor model
         """
         raw_contributor = self.get_endpoint("contributors").update(
-            params=params,
-            parent_id=project_id,
-            resource_id=contributor_id
+            params=params, parent_id=project_id, resource_id=contributor_id
         )
         return ContributorModel(raw_contributor)
 
-    def delete_contributor(self, project_id: str,
-                           contributor_id: Union[str, int]) -> Dict:
+    def delete_contributor(self, project_id: str, contributor_id: str | int) -> dict[str, Any]:
         """Deletes a contributor.
 
         :param str project_id: ID of the project
@@ -100,6 +94,7 @@ class ContributorMethods(EndpointProviderMixin):
         :return: Dictionary with project ID and "contributor_deleted" set to True
         :rtype dict:
         """
-        response = self.get_endpoint("contributors"). \
-            delete(parent_id=project_id, resource_id=contributor_id)
+        response = self.get_endpoint("contributors").delete(
+            parent_id=project_id, resource_id=contributor_id
+        )
         return response
