@@ -4,12 +4,12 @@ lokalise.collections.contributors
 Module containing contributors collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.contributor import ContributorModel
+from .base_collection import BaseCollection
 
 
-class ContributorsCollection(BaseCollection):
-    """Describes project contributors.
-    """
+class ContributorsCollection(BaseCollection[ContributorModel]):
+    """Describes project contributors."""
+
     DATA_KEY = "contributors"
     MODEL_KLASS = ContributorModel
