@@ -4,12 +4,12 @@ lokalise.collections.payment_cards
 Module containing payment cards collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.payment_card import PaymentCardModel
+from .base_collection import BaseCollection
 
 
-class PaymentCardsCollection(BaseCollection):
-    """Describes payment cards.
-    """
+class PaymentCardsCollection(BaseCollection[PaymentCardModel]):
+    """Describes payment cards."""
+
     DATA_KEY = "payment_cards"
     MODEL_KLASS = PaymentCardModel
