@@ -4,12 +4,12 @@ lokalise.collections.queued_processes
 Module containing queued processes collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.queued_process import QueuedProcessModel
+from .base_collection import BaseCollection
 
 
-class QueuedProcessesCollection(BaseCollection):
-    """Describes queued processes.
-    """
+class QueuedProcessesCollection(BaseCollection[QueuedProcessModel]):
+    """Describes queued processes."""
+
     DATA_KEY = "processes"
     MODEL_KLASS = QueuedProcessModel
