@@ -4,12 +4,12 @@ lokalise.collections.tasks
 Module containing tasks collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.task import TaskModel
+from .base_collection import BaseCollection
 
 
-class TasksCollection(BaseCollection):
-    """Describes tasks.
-    """
+class TasksCollection(BaseCollection[TaskModel]):
+    """Describes tasks."""
+
     DATA_KEY = "tasks"
     MODEL_KLASS = TaskModel
