@@ -4,12 +4,12 @@ lokalise.collections.team_users
 Module containing team users collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.team_user import TeamUserModel
+from .base_collection import BaseCollection
 
 
-class TeamUsersCollection(BaseCollection):
-    """Describes team users.
-    """
+class TeamUsersCollection(BaseCollection[TeamUserModel]):
+    """Describes team users."""
+
     DATA_KEY = "team_users"
     MODEL_KLASS = TeamUserModel
