@@ -4,12 +4,12 @@ lokalise.collections.translation_providers
 Module containing translation providers collection.
 """
 
-from .base_collection import BaseCollection
 from ..models.translation_provider import TranslationProviderModel
+from .base_collection import BaseCollection
 
 
-class TranslationProvidersCollection(BaseCollection):
-    """Describes translation providers.
-    """
+class TranslationProvidersCollection(BaseCollection[TranslationProviderModel]):
+    """Describes translation providers."""
+
     DATA_KEY = "translation_providers"
     MODEL_KLASS = TranslationProviderModel
