@@ -8,10 +8,6 @@ from .base_model import BaseModel
 
 
 class FileModel(BaseModel):
-    """Describes file.
-    """
-    ATTRS = [
-        'file_id',
-        'filename',
-        'key_count'
-    ]
+    """Describes file."""
+
+    ATTRS = ["file_id", "filename", "key_count"]
