@@ -8,16 +8,15 @@ from .base_model import BaseModel
 
 
 class PermissionTemplateModel(BaseModel):
-    """Describes permission template.
-    """
+    """Describes permission template."""
 
     ATTRS = [
-        'id',
-        'role',
-        'permissions',
-        'description',
-        'tag',
-        'tagColor',
-        'tagInfo',
-        'doesEnableAllReadOnlyLanguages',
+        "id",
+        "role",
+        "permissions",
+        "description",
+        "tag",
+        "tagColor",
+        "tagInfo",
+        "doesEnableAllReadOnlyLanguages",
     ]
