@@ -8,15 +8,15 @@ from .base_model import BaseModel
 
 
 class TranslationProviderModel(BaseModel):
-    """Describes translation provider model.
-    """
+    """Describes translation provider model."""
+
     ATTRS = [
-        'provider_id',
-        'name',
-        'slug',
-        'price_pair_min',
-        'website_url',
-        'description',
-        'tiers',
-        'pairs'
+        "provider_id",
+        "name",
+        "slug",
+        "price_pair_min",
+        "website_url",
+        "description",
+        "tiers",
+        "pairs",
     ]
