@@ -8,12 +8,8 @@ from .base_model import BaseModel
 
 
 class TranslationStatusModel(BaseModel):
-    """Describes translation status model.
-    """
+    """Describes translation status model."""
+
     DATA_KEY = "custom_translation_status"
 
-    ATTRS = [
-        "status_id",
-        "title",
-        "color"
-    ]
+    ATTRS = ["status_id", "title", "color"]
